pub struct DualQuat {
pub real: Quat,
pub dual: Quat,
}Expand description
A dual quaternion representing a rigid body transformation.
real encodes the rotation, dual encodes the translation as:
dual = 0.5 * Quat(t.x, t.y, t.z, 0) * real
Fields
real: QuatRotation part (unit quaternion).
dual: QuatTranslation-encoding part.
Implementations
Sourceimpl DualQuat
impl DualQuat
Sourcepub fn from_rotation_translation(rot: Quat, translation: Vec3) -> Self
pub fn from_rotation_translation(rot: Quat, translation: Vec3) -> Self
Creates a dual quaternion from a rotation quaternion and translation vector.
Sourcepub fn to_rotation_translation(&self) -> (Quat, Vec3)
pub fn to_rotation_translation(&self) -> (Quat, Vec3)
Extracts the rotation quaternion and translation vector.