pub fn create_slice_plane_bind_group_layout(device: &Device) -> BindGroupLayoutExpand description
Creates the bind group layout for slice plane rendering.
pub fn create_slice_plane_bind_group_layout(device: &Device) -> BindGroupLayoutCreates the bind group layout for slice plane rendering.